summaryrefslogtreecommitdiffstats
path: root/Makefile.PL
diff options
context:
space:
mode:
authorColin Guthrie <colin@mageia.org>2013-10-12 16:47:43 +0100
committerColin Guthrie <colin@mageia.org>2013-10-12 17:44:09 +0100
commiteb8f6e900feccc2b7667289135f821438717ec8c (patch)
tree8f55d31bb65192ca7d56190aaf61f29eec6bed4f /Makefile.PL
parent6c4ae17acfb5159eeac92b92fdca112ca2ede4ec (diff)
downloadurpmi-eb8f6e900feccc2b7667289135f821438717ec8c.tar
urpmi-eb8f6e900feccc2b7667289135f821438717ec8c.tar.gz
urpmi-eb8f6e900feccc2b7667289135f821438717ec8c.tar.bz2
urpmi-eb8f6e900feccc2b7667289135f821438717ec8c.tar.xz
urpmi-eb8f6e900feccc2b7667289135f821438717ec8c.zip
Use polkit for authorisation (mga#11125)
Diffstat (limited to 'Makefile.PL')
-rwxr-xr-xMakefile.PL32
1 files changed, 19 insertions, 13 deletions
diff --git a/Makefile.PL b/Makefile.PL
index 44fba5d3..ed39b155 100755
--- a/Makefile.PL
+++ b/Makefile.PL
@@ -13,14 +13,16 @@ use ExtUtils::MakeMaker;
# --install-gui : install gurpmi
my $with_rpm = 1; $with_rpm = 0 if grep $_ eq '--without-rpm', @ARGV;
my $with_po = 0; $with_po = 1 if grep $_ eq '--install-po', @ARGV;
+my $with_polkit = 0; $with_polkit = 1 if grep $_ eq '--install-polkit', @ARGV;
my $with_gui = 0; $with_gui = 1 if grep $_ eq '--install-gui', @ARGV;
# All scripts, some of them go in /usr/sbin (see DESTINSTALLSBIN below)
our @bin_scripts = qw(urpmq urpmf rpm-find-leaves);
-our @sbin_scripts = qw(urpmi urpme urpmi.addmedia urpmi.update urpmi.removemedia rurpmi rurpme);
+our @sbin_scripts = qw(urpmi urpme urpmi.addmedia urpmi.removemedia rurpmi rurpme);
+our @libexec_scripts = qw(urpmi.update);
if ($with_gui) {
push @bin_scripts, qw(gurpmi);
- push @sbin_scripts, qw(gurpmi2);
+ push @libexec_scripts, qw(gurpmi2);
}
# And now, add some functionality to MakeMaker.
@@ -32,10 +34,10 @@ sub libscan {
return !$with_gui && $path =~ /gurpmi/ ? '' : $path;
}
# Make proper sbin/man5/man8 dirs in blib
sub top_targets {
my $inherited = shift->SUPER::top_targets(@_);
- $inherited =~ s/^config ::/$& \$(INST_MAN5DIR)\$(DIRFILESEP).exists \$(INST_MAN8DIR)\$(DIRFILESEP).exists \$(INST_SBIN)\$(DIRFILESEP).exists/m;
+ $inherited =~ s/^config ::/$& \$(INST_MAN5DIR)\$(DIRFILESEP).exists \$(INST_MAN8DIR)\$(DIRFILESEP).exists \$(INST_SBIN)\$(DIRFILESEP).exists \$(INST_LIBEXEC)\$(DIRFILESEP).exists/m;
$inherited;
}
@@ -45,8 +47,10 @@ sub installbin {
my $inherited = $self->SUPER::installbin(@_);
my $s = join '|', map quotemeta, @sbin_scripts;
$inherited =~ s{\$\(INST_SCRIPT\)/($s)}{\$(INST_SBIN)/$1}g;
+ $s = join '|', map quotemeta, @libexec_scripts;
+ $inherited =~ s{\$\(INST_SCRIPT\)/($s)}{\$(INST_LIBEXEC)/$1}g;
# how to create needed directories under blib
- $inherited .= $self->dir_target("\$(INST_$_)") for qw(SBIN MAN5DIR MAN8DIR);
+ $inherited .= $self->dir_target("\$(INST_$_)") for qw(SBIN LIBEXEC MAN5DIR MAN8DIR);
$inherited;
}
@@ -54,11 +58,12 @@ sub install {
my $inherited = shift->SUPER::install(@_);
# Take into account scripts in sbin under blib
# and new manpage sections
- $inherited =~ s/\$\(INST_BIN\) \$\(DESTINSTALL(\w*)BIN\)/$& \$(INST_SBIN) \$(DESTINSTALL$1SBIN) \$(INST_MAN5DIR) \$(DESTINSTALLMAN5DIR) \$(INST_MAN8DIR) \$(DESTINSTALLMAN8DIR)/g;
+ $inherited =~ s/\$\(INST_BIN\) \$\(DESTINSTALL(\w*)BIN\)/$& \$(INST_SBIN) \$(DESTINSTALL$1SBIN) \$(INST_LIBEXEC) \$(DESTINSTALLLIBEXECDIR) \$(INST_MAN5DIR) \$(DESTINSTALLMAN5DIR) \$(INST_MAN8DIR) \$(DESTINSTALLMAN8DIR)/g;
# install files under /etc and /var
my $po = $with_po ? ' installpo' : '';
+ my $polkit = $with_polkit ? ' installpolkit' : '';
my $gui = $with_gui ? ' installgurpmi2' : '';
- $inherited =~ s/^install ::/$& installconfigfiles installstatedir$po$gui/gm;
+ $inherited =~ s/^install ::/$& installconfigfiles installstatedir$po$polkit$gui/gm;
$inherited;
}
@@ -97,6 +102,9 @@ sub postamble {
installpo:
\$(MAKE) -C po install
+installpolkit:
+ \$(MAKE) -C polkit install
+
installconfigfiles:
install -d \$(SYSCONFDIR)/urpmi
install -m 644 inst.list skip.list \$(SYSCONFDIR)/urpmi
@@ -108,11 +116,6 @@ installstatedir:
install -d \$(DESTDIR)/var/cache/urpmi/rpms
installgurpmi2: pure_install gurpmi.desktop
- ln -s -f consolehelper \$(DESTINSTALLSCRIPT)/gurpmi2
-
-ChangeLog:
- svn2cl --accum --authors ${commonusername}username.xml
- rm -f *.bak
TAGS:
etags *.pm */*.pm
@@ -143,18 +146,21 @@ WriteMakefile(
DESTINSTALLSBIN => '$(DESTINSTALLBIN)/../sbin',
DESTINSTALLSITESBIN => '$(DESTINSTALLSITEBIN)/../sbin',
DESTINSTALLVENDORSBIN => '$(DESTINSTALLVENDORBIN)/../sbin',
+ INSTALLLIBEXECDIR => '$(PERLPREFIX)/libexec',
+ DESTINSTALLLIBEXECDIR => '$(DESTDIR)$(INSTALLLIBEXECDIR)',
INSTALLMAN5DIR => '$(PERLPREFIX)/share/man/man5',
DESTINSTALLMAN5DIR => '$(DESTDIR)$(INSTALLMAN5DIR)',
INSTALLMAN8DIR => '$(PERLPREFIX)/share/man/man8',
DESTINSTALLMAN8DIR => '$(DESTDIR)$(INSTALLMAN8DIR)',
INST_SBIN => 'blib/sbin',
+ INST_LIBEXEC => 'blib/libexec',
INST_MAN5DIR => 'blib/man5',
INST_MAN8DIR => 'blib/man8',
# We could read those values from rpm macros.
SYSCONFDIR => '$(DESTDIR)/etc',
LOCALSTATEDIR => '$(DESTDIR)/var/lib',
},
- EXE_FILES => [ @bin_scripts, @sbin_scripts ],
+ EXE_FILES => [ @bin_scripts, @sbin_scripts, @libexec_scripts ],
PMLIBDIRS => [ qw(gurpm urpm) ],
$with_po ? (DIR => [ 'po' ]) : (),
MAN1PODS => {
@@ -32,10 +34,10 @@ sub libscan {
return !$with_gui && $path =~ /gurpmi/ ? '' : $path;
}
-# Make proper sbin/man5/man8 dirs in blib
+# Make proper sbin/libexec/man5/man8 dirs in blib
sub top_targets {
my $inherited = shift->SUPER::top_targets(@_);